@@ -13,9 +13,11 @@ def run():
     application = QApplication(sys.argv)
     window = main_window.MainWindow()
     logger = logging.getLogger()
-    add_rotating_file_handler_to_logger(logger,
-                log_dir=window.app_data.config.log_dir,
-                file_max_number=window.app_data.config.log_max_file_number)
+    add_rotating_file_handler_to_logger(
+        logger,
+        log_dir=window.app_data.config.log_dir,
+        file_max_number=window.app_data.config.log_max_file_number,
+    )
     window.show()
     return application.exec_()
 
