@@ -4,15 +4,15 @@ from typing import Callable, Optional
 
 from PySide2 import QtCore, QtWidgets
 from PySide2.QtCore import QItemSelectionModel
-from PySide2.QtWidgets import QPushButton, QLabel
+from PySide2.QtWidgets import QPushButton, QLabel, QCheckBox, QWidget
 
+from .model import AppData
 from .parallel import Worker
 from ..utils.progress import ProgressInterface
 
 
 class MandatoryLabel(QLabel):
-    """A label extension which appends a '*' to label's end to mark the field as required.
-    """
+    """A label extension which appends a '*' to label's end to mark the field as required."""
 
     def __init__(self, label: str):
         super().__init__(label + " <sup><font color='red'>*</font></sup>")
@@ -81,8 +81,7 @@ class ConsoleWidget(QtWidgets.QGroupBox):
 class PathInput:
     """Path selection widget with a select button and a show path field."""
 
-    def __init__(self, directory=True, path: Optional[Path] = Path.home(),
-                 parent=None):
+    def __init__(self, directory=True, path: Optional[Path] = Path.home(), parent=None):
         self.parent = parent
         self.text = QtWidgets.QLineEdit(parent)
         self.text.setReadOnly(True)
@@ -107,10 +106,12 @@ class PathInput:
             location = Path.home()
         if directory:
             new_path = QtWidgets.QFileDialog.getExistingDirectory(
-                self.parent, "Select Directory", str(location))
+                self.parent, "Select Directory", str(location)
+            )
         else:
             new_path, _ = QtWidgets.QFileDialog.getOpenFileName(
-                self.parent, "Select File", str(location))
+                self.parent, "Select File", str(location)
+            )
         if new_path:
             self.update_path(Path(new_path))
 
@@ -158,8 +159,7 @@ class TabMixin:
         self.btn_test.setEnabled(enabled)
         self.btn_test.repaint()
 
-    def create_run_panel(self, panel_name: str, action: Callable,
-                         action_name: str):
+    def create_run_panel(self, panel_name: str, action: Callable, action_name: str):
         self.run_panel = QtWidgets.QGroupBox(panel_name)
         layout = QtWidgets.QHBoxLayout()
         self.btn_test = TabMixin._create_disabled_button("Test")
@@ -176,12 +176,10 @@ class TabMixin:
 
     def add_worker_actions(self, worker: Worker):
         """Attach GUI-updating signals to worker"""
-        worker.signals.started.connect(
-            lambda: self.run_panel.setEnabled(False))
+        worker.signals.started.connect(lambda: self.run_panel.setEnabled(False))
         worker.signals.logging.connect(self.console.write)
         worker.signals.error.connect(lambda e: self.console.append(str(e[1])))
-        worker.signals.finished.connect(
-            lambda: self.run_panel.setEnabled(True))
+        worker.signals.finished.connect(lambda: self.run_panel.setEnabled(True))
 
 
 def run_dialog(parent, msg: str, password: bool = True):
@@ -193,3 +191,52 @@ def run_dialog(parent, msg: str, password: bool = True):
     if dialog_pwd.exec_() != QtWidgets.QDialog.Accepted or not dialog_pwd.textValue():
         return None
     return dialog_pwd.textValue()
+
+
+def create_verify_dtr_checkbox(
+    app_data: AppData, field_name: str, parent: Optional[QWidget] = None
+) -> QCheckBox:
+    verify_dtr = QtWidgets.QCheckBox("Verify DTR ID", parent)
+    verify_dtr.setStatusTip("Verify DTR (Data Transfer Request) ID")
+    verify_dtr.setChecked(not app_data.config.offline and app_data.encrypt_verify_dtr)
+    if app_data.config.offline:
+        verify_dtr.setEnabled(not app_data.config.offline)
+        verify_dtr.setStatusTip(
+            "Verifying Transfer Request ID in offline mode is not possible"
+        )
+    verify_dtr.stateChanged.connect(
+        lambda state: setattr(app_data, field_name, state == QtCore.Qt.Checked)
+    )
+    return verify_dtr
+
+
+class FieldMapping:
+    def __init__(self):
+        self._mapping = {}
+
+    def bind_text(self, field_name, w):
+        self._mapping[field_name] = w.setText
+        return w
+
+    def bind_checked(self, field_name, w):
+        self._mapping[field_name] = w.setChecked
+        return w
+
+    def bind_value(self, field_name, w):
+        self._mapping[field_name] = w.setValue
+        return w
+
+    def bind_path(self, field_name, w):
+        self._mapping[field_name] = lambda p: w.update_path(p and Path(p))
+        return w
+
+    def load(self, parameters):
+        for key, val in parameters.items():
+            try:
+                self._mapping[key](val)
+            except KeyError:
+                raise ValueError(
+                    f"Invalid field `{key}` found in your config file"
+                ) from None
+        for key in set(self._mapping.keys()) - set(parameters.keys()):
+            self._mapping[key](None)
