@@ -16,9 +16,8 @@ class DecryptTab(QtWidgets.QWidget, TabMixin):
 
         files_panel = self.create_files_panel()
         decrypt_options_panel = self.create_decrypt_options_panel()
-        self.create_run_panel("Decrypt data", self.decrypt,
-                              "Decrypt selected files")
-        self.app_data.add_listener('decrypt_files', self._enable_buttons)
+        self.create_run_panel("Decrypt data", self.decrypt, "Decrypt selected files")
+        self.app_data.add_listener("decrypt_files", self._enable_buttons)
         self.create_console()
         self.create_progress_bar()
 
@@ -36,27 +35,29 @@ class DecryptTab(QtWidgets.QWidget, TabMixin):
     def create_files_panel(self):
         box = ArchiveOnlyFileSelectionWidget("Files to decrypt", self)
         box.file_list_model.layoutChanged.connect(
-            lambda: setattr(self.app_data, "decrypt_files", box.get_list()))
+            lambda: setattr(self.app_data, "decrypt_files", box.get_list())
+        )
         return box
 
     def create_decrypt_options_panel(self):
         box = QtWidgets.QGroupBox("Output")
 
         group_extract = QtWidgets.QButtonGroup(box)
-        btn_decrypt_and_extract = QtWidgets.QRadioButton(
-            "Decrypt and unpack files")
-        btn_decrypt_and_extract.setChecked(
-            not self.app_data.decrypt_decrypt_only)
+        btn_decrypt_and_extract = QtWidgets.QRadioButton("Decrypt and unpack files")
+        btn_decrypt_and_extract.setChecked(not self.app_data.decrypt_decrypt_only)
         btn_decrypt_only = QtWidgets.QRadioButton("Decrypt only")
         btn_decrypt_only.toggled.connect(
-            lambda: setattr(self.app_data, "decrypt_decrypt_only",
-                            btn_decrypt_only.isChecked()))
+            lambda: setattr(
+                self.app_data, "decrypt_decrypt_only", btn_decrypt_only.isChecked()
+            )
+        )
         group_extract.addButton(btn_decrypt_and_extract)
         group_extract.addButton(btn_decrypt_only)
         output_location = PathInput(path=self.app_data.encrypt_output_location)
         output_location.status_tip = "Destination folder for the decrypted packages"
         output_location.on_path_change(
-            partial(setattr, self.app_data, "decrypt_output_location"))
+            partial(setattr, self.app_data, "decrypt_output_location")
+        )
 
         layout = QtWidgets.QGridLayout(self)
         layout.addWidget(btn_decrypt_and_extract, 0, 0)
@@ -86,6 +87,7 @@ class DecryptTab(QtWidgets.QWidget, TabMixin):
             passphrase=pw,
             dry_run=dry_run,
             progress=progress,
-            on_error=lambda _: None)
+            on_error=lambda _: None,
+        )
         self.add_worker_actions(worker)
         self.threadpool.start(worker)
