@@ -4,8 +4,15 @@ from functools import partial
 from PySide2 import QtWidgets, QtCore, QtGui
 from PySide2.QtWidgets import QHeaderView, QLabel
 
-from .component import TabMixin, PathInput, GuiProgress, \
-    run_dialog, SelectionButton, MandatoryLabel
+from .component import (
+    TabMixin,
+    PathInput,
+    GuiProgress,
+    run_dialog,
+    SelectionButton,
+    MandatoryLabel,
+    create_verify_dtr_checkbox,
+)
 from .file_selection_widget import DirectoryAndFileSelectionWidget
 from .model import TableModel
 from .parallel import Worker
@@ -22,10 +29,11 @@ class EncryptTab(QtWidgets.QWidget, TabMixin):
         self.app_data = self.parent().app_data
 
         files_panel = self.create_files_panel()
-        self.create_run_panel("Package and encrypt data", self.encrypt,
-                              "Package && Encrypt")
-        self.app_data.add_listener('encrypt_files', self._enable_buttons)
-        self.app_data.add_listener('encrypt_recipients', self._enable_buttons)
+        self.create_run_panel(
+            "Package and encrypt data", self.encrypt, "Package && Encrypt"
+        )
+        self.app_data.add_listener("encrypt_files", self._enable_buttons)
+        self.app_data.add_listener("encrypt_recipients", self._enable_buttons)
         self.create_console()
         self.create_progress_bar()
 
@@ -36,14 +44,18 @@ class EncryptTab(QtWidgets.QWidget, TabMixin):
         self.layout().addWidget(self.progress_bar)
 
     def _enable_buttons(self):
-        self.set_buttons_enabled(len(self.app_data.encrypt_recipients) > 0 and
-                                 len(self.app_data.encrypt_files) > 0)
+        self.set_buttons_enabled(
+            len(self.app_data.encrypt_recipients) > 0
+            and len(self.app_data.encrypt_files) > 0
+        )
 
     def create_files_panel(self):
         box = DirectoryAndFileSelectionWidget(
-            "Files and/or directories to encrypt", self)
+            "Files and/or directories to encrypt", self
+        )
         box.file_list_model.layoutChanged.connect(
-            lambda: setattr(self.app_data, "encrypt_files", box.get_list()))
+            lambda: setattr(self.app_data, "encrypt_files", box.get_list())
+        )
         return box
 
     def create_user_panel(self):
@@ -57,40 +69,47 @@ class EncryptTab(QtWidgets.QWidget, TabMixin):
         recipients_input_view.setModel(self.app_data.pub_keys_model)
 
         recipients_output_view = QtWidgets.QTableView()
-        recipients_output_model = TableModel(
-            columns=("Name", "Email", "Fingerprint"))
+        recipients_output_model = TableModel(columns=("Name", "Email", "Fingerprint"))
         recipients_output_view.setModel(recipients_output_model)
         recipients_output_view.verticalHeader().hide()
-        recipients_output_view.horizontalHeader().setSectionResizeMode(QHeaderView.ResizeToContents)
+        recipients_output_view.horizontalHeader().setSectionResizeMode(
+            QHeaderView.ResizeToContents
+        )
         recipients_output_view.horizontalHeader().setStretchLastSection(True)
-        recipients_output_view.setSelectionBehavior(
-            QtWidgets.QTableView.SelectRows)
+        recipients_output_view.setSelectionBehavior(QtWidgets.QTableView.SelectRows)
         recipients_output_view.setSelectionMode(
-            QtWidgets.QTableView.SelectionMode.SingleSelection)
+            QtWidgets.QTableView.SelectionMode.SingleSelection
+        )
 
         recipients_btn_add = QtWidgets.QPushButton("+")
         recipients_btn_add.setStatusTip("Add recipient to the list")
-        recipients_btn_remove = SelectionButton("Remove selected recipients",
-                                                recipients_output_view.selectionModel())
+        recipients_btn_remove = SelectionButton(
+            "Remove selected recipients", recipients_output_view.selectionModel()
+        )
 
         def update_sender(index):
-            self.app_data.encrypt_sender = "" if index == -1 else \
-                self.app_data.priv_keys_model.get_value(index).fingerprint
+            self.app_data.encrypt_sender = (
+                ""
+                if index == -1
+                else self.app_data.priv_keys_model.get_value(index).fingerprint
+            )
 
         def update_recipients(index):
-            self.app_data.encrypt_recipients = [x[2] for x in
-                                                index.model().get_data()]
+            self.app_data.encrypt_recipients = [x[2] for x in index.model().get_data()]
 
         def add_recipient():
             key = recipients_input_view.model().get_value(
-                recipients_input_view.currentIndex())
+                recipients_input_view.currentIndex()
+            )
             row = (key.uids[0].full_name, key.uids[0].email, key.fingerprint)
             recipients_output_model.set_data(
-                set(recipients_output_model.get_data()) | set([row]))
+                set(recipients_output_model.get_data()) | set([row])
+            )
 
         def remove_recipient():
-            recipients_output_view.model() \
-                .removeRows(recipients_output_view.currentIndex().row(), 1)
+            recipients_output_view.model().removeRows(
+                recipients_output_view.currentIndex().row(), 1
+            )
             recipients_output_view.clearSelection()
 
         # Connect actions
@@ -102,7 +121,9 @@ class EncryptTab(QtWidgets.QWidget, TabMixin):
         update_sender(sender_widget.currentIndex())
 
         layout = QtWidgets.QGridLayout(group_box)
-        layout.addWidget(QLabel("Select data sender and add at least one recipient"), 0, 0, 1, 3)
+        layout.addWidget(
+            QLabel("Select data sender and add at least one recipient"), 0, 0, 1, 3
+        )
         layout.addWidget(MandatoryLabel("Sender"), 1, 0, 1, 1)
         layout.addWidget(sender_widget, 1, 1, 1, 1)
         layout.addWidget(recipients_input_view, 2, 1, 1, 1)
@@ -131,20 +152,26 @@ class EncryptTab(QtWidgets.QWidget, TabMixin):
         compress.setStatusTip("Compress input data files before encryption")
         compress.setChecked(self.app_data.encrypt_compress)
         output_suffix = QtWidgets.QLineEdit(group_box)
-        output_suffix.setStatusTip("(optional) File name suffix in the "
-                                   "format datetime_suffix.tar")
+        output_suffix.setStatusTip(
+            "(optional) File name suffix in the " "format datetime_suffix.tar"
+        )
         output_suffix.setValidator(QtGui.QRegExpValidator(QtCore.QRegExp(r"[\w-]*")))
         output_location = PathInput(path=self.app_data.encrypt_output_location)
         output_location.status_tip = "Destination folder for the encrypted package"
         # Add actions
-        compress.stateChanged.connect(lambda state:
-                                      setattr(self.app_data, "encrypt_compress",
-                                              state == QtCore.Qt.Checked))
+        compress.stateChanged.connect(
+            lambda state: setattr(
+                self.app_data, "encrypt_compress", state == QtCore.Qt.Checked
+            )
+        )
         output_suffix.editingFinished.connect(
-            lambda: setattr(self.app_data, "encrypt_output_suffix",
-                            output_suffix.text()))
+            lambda: setattr(
+                self.app_data, "encrypt_output_suffix", output_suffix.text()
+            )
+        )
         output_location.on_path_change(
-            partial(setattr, self.app_data, "encrypt_output_location"))
+            partial(setattr, self.app_data, "encrypt_output_location")
+        )
 
         group_box.layout().addWidget(QLabel("Suffix"), 0, 0, 1, 1)
         group_box.layout().addWidget(output_suffix, 0, 1, 1, 1)
@@ -160,16 +187,10 @@ class EncryptTab(QtWidgets.QWidget, TabMixin):
         # Create fields
         transfer_id = QtWidgets.QLineEdit(group_box)
         transfer_id.setStatusTip("(optional) Data Transfer Request ID")
-        transfer_id.setValidator(QtGui.QIntValidator(1, 10**9))
-        verify_dtr = QtWidgets.QCheckBox("Verify DTR ID", group_box)
-        verify_dtr.setStatusTip("Verify DTR (Data Transfer Request) ID")
-        verify_dtr.setChecked(not self.app_data.config.offline and self.app_data.encrypt_verify_dtr)
-        if self.app_data.config.offline:
-            verify_dtr.setEnabled(not self.app_data.config.offline)
-            verify_dtr.setStatusTip("Verifying Transfer Request ID in offline mode is not possible")
-        verify_dtr.stateChanged.connect(lambda state:
-            setattr(self.app_data, "encrypt_verify_dtr",
-                    state == QtCore.Qt.Checked))
+        transfer_id.setValidator(QtGui.QIntValidator(1, 10 ** 9))
+        verify_dtr = create_verify_dtr_checkbox(
+            self.app_data, "encrypt_verify_dtr", group_box
+        )
         purpose = QtWidgets.QComboBox(group_box)
         purpose.setStatusTip("(optional) Purpose of the package")
         purpose.addItems(("",) + tuple(Purpose.__members__.keys()))
@@ -180,9 +201,11 @@ class EncryptTab(QtWidgets.QWidget, TabMixin):
             self.app_data.encrypt_transfer_id = int(text) if text else None
 
         transfer_id.textChanged.connect(on_transfer_id_changed)
-        purpose.currentTextChanged.connect(lambda text:
-                                           setattr(self.app_data, "encrypt_purpose",
-                                                   None if text == "" else Purpose(text)))
+        purpose.currentTextChanged.connect(
+            lambda text: setattr(
+                self.app_data, "encrypt_purpose", None if text == "" else Purpose(text)
+            )
+        )
         group_box.layout().addWidget(QLabel("DTR ID"), 0, 0, 1, 1)
         group_box.layout().addWidget(transfer_id, 0, 1, 1, 1)
         group_box.layout().addWidget(verify_dtr, 1, 0, 1, 2)
@@ -194,11 +217,17 @@ class EncryptTab(QtWidgets.QWidget, TabMixin):
         progress = GuiProgress()
         progress.updated.connect(self.progress_bar.setValue)
         output_path = str(
-            self.app_data.encrypt_output_location /
-            "_".join(filter(None,
-                            [datetime.now().astimezone().strftime(
-                                encrypt.DATE_FMT_FILENAME),
-                                self.app_data.encrypt_output_suffix])))
+            self.app_data.encrypt_output_location
+            / "_".join(
+                filter(
+                    None,
+                    [
+                        datetime.now().astimezone().strftime(encrypt.DATE_FMT_FILENAME),
+                        self.app_data.encrypt_output_suffix,
+                    ],
+                )
+            )
+        )
         if not dry_run and self.app_data.config.sign_encrypted_data:
             pw = run_dialog(self, "Enter password for your GPG key")
             if pw is None:
@@ -221,6 +250,7 @@ class EncryptTab(QtWidgets.QWidget, TabMixin):
             compression_level=None if self.app_data.encrypt_compress else 0,
             purpose=self.app_data.encrypt_purpose,
             progress=progress,
-            on_error=lambda _: None)
+            on_error=lambda _: None,
+        )
         self.add_worker_actions(worker)
         self.threadpool.start(worker)
