@@ -19,7 +19,8 @@ class FileSelectionWidget(QtWidgets.QGroupBox):
         self.file_list_view = QtWidgets.QListView(self)
         self.file_list_view.setModel(self.file_list_model)
         self.file_list_view.setSelectionMode(
-            QtWidgets.QAbstractItemView.ExtendedSelection)
+            QtWidgets.QAbstractItemView.ExtendedSelection
+        )
         self.file_list_view.setLayout(QtWidgets.QVBoxLayout())
 
         buttons = self._create_buttons()
@@ -36,11 +37,14 @@ class FileSelectionWidget(QtWidgets.QGroupBox):
         return self.file_list_model.stringList()
 
     def _create_buttons(self) -> List[QAbstractButton]:
-        return [self._create_add_files_button(), self._create_remove_selected_button(),
-                self._create_clear_list_button()]
+        return [
+            self._create_add_files_button(),
+            self._create_remove_selected_button(),
+            self._create_clear_list_button(),
+        ]
 
     def _create_add_files_button(self) -> QAbstractButton:
-        button = QtWidgets.QPushButton('Add files', self)
+        button = QtWidgets.QPushButton("Add files", self)
         button.clicked.connect(self._add_files)
         return button
 
@@ -51,8 +55,9 @@ class FileSelectionWidget(QtWidgets.QGroupBox):
                 self.file_list_model.removeRows(index.row(), 1)
             self.file_list_model.layoutChanged.emit()
 
-        button = SelectionButton('Remove selected',
-                                 self.file_list_view.selectionModel())
+        button = SelectionButton(
+            "Remove selected", self.file_list_view.selectionModel()
+        )
         button.clicked.connect(clear_selected)
         return button
 
@@ -63,7 +68,7 @@ class FileSelectionWidget(QtWidgets.QGroupBox):
             self.file_list_model.setStringList([])
             self.file_list_model.layoutChanged.emit()
 
-        button = QtWidgets.QPushButton('Clear list', self)
+        button = QtWidgets.QPushButton("Clear list", self)
         button.clicked.connect(clear_list)
         return button
 
@@ -72,7 +77,8 @@ class FileSelectionWidget(QtWidgets.QGroupBox):
         if paths:
             self.path = Path(next(iter(paths))).parent
         self.file_list_model.setStringList(
-            sorted(set(self.file_list_model.stringList()) | paths))
+            sorted(set(self.file_list_model.stringList()) | paths)
+        )
         self.file_list_model.layoutChanged.emit()
 
     def _add_files(self):
@@ -99,11 +105,12 @@ class DirectoryAndFileSelectionWidget(FileSelectionWidget):
 
     def _create_add_directory_button(self):
         def add_directory():
-            directory = (QtWidgets.QFileDialog.getExistingDirectory(
-                self, 'Select directory', str(self.path)))
+            directory = QtWidgets.QFileDialog.getExistingDirectory(
+                self, "Select directory", str(self.path)
+            )
             self._update_paths((directory,))
 
-        button = QtWidgets.QPushButton('Add directory', self)
+        button = QtWidgets.QPushButton("Add directory", self)
         button.clicked.connect(add_directory)
         return button
 
