@@ -4,8 +4,16 @@ from PySide2 import QtWidgets, QtGui, QtCore
 from PySide2.QtCore import QSysInfo
 from PySide2.QtGui import QKeySequence
 
-from sett import APP_NAME_LONG, URL_READTHEDOCS, URL_GITLAB_ISSUES, \
-    APP_NAME_SHORT, __version__, URL_GITLAB, VERSION_WITH_DEPS
+from sett import (
+    APP_NAME_LONG,
+    URL_READTHEDOCS,
+    URL_GITLAB_ISSUES,
+    APP_NAME_SHORT,
+    __version__,
+    URL_GITLAB,
+    VERSION_WITH_DEPS,
+)
+from .settings_tab import SettingsTab, config_to_settings
 from ..core.versioncheck import check_version
 from .keys_tab import KeysTab
 from .transfer_tab import TransferTab
@@ -13,7 +21,7 @@ from .decrypt_tab import DecryptTab
 from .encrypt_tab import EncryptTab
 from .model import AppData
 from .parallel import Worker
-from ..utils.config import load_config
+from ..utils.config import load_config, save_config, config_to_dict
 
 QtCore.QThreadPool.globalInstance().setExpiryTimeout(-1)
 
@@ -21,26 +29,37 @@ QtCore.QThreadPool.globalInstance().setExpiryTimeout(-1)
 class MainWindow(QtWidgets.QMainWindow):
     def __init__(self):
         super().__init__()
-
         self.title = f"{APP_NAME_LONG} ({__version__})"
-        self.app_data = AppData(config=load_config())
+        self.app_data = AppData(config=self.get_config())
         self.setWindowTitle(self.title)
         self.add_menu()
         self.add_tabs()
         self.add_status_bar()
         self.check_version()
 
+    def get_config(self):
+        with warnings.catch_warnings(record=True) as w:
+            config = load_config()
+            if w:
+                self.show_warning(
+                    "Configuration Error",
+                    "\n".join(format(warning.message) for warning in w),
+                )
+        return config
+
     def add_tabs(self):
         tab_keys = KeysTab(self)  # FIXME created first to populate gpg keys
         tab_encrypt = EncryptTab(self)
         tab_decrypt = DecryptTab(self)
         tab_transfer = TransferTab(self)
+        tab_settings = SettingsTab(self)
 
         tabs = QtWidgets.QTabWidget()
         tabs.addTab(tab_encrypt, "&Encrypt")
         tabs.addTab(tab_transfer, "&Transfer")
         tabs.addTab(tab_decrypt, "&Decrypt")
         tabs.addTab(tab_keys, "&Keys")
+        tabs.addTab(tab_settings, "&Settings")
 
         self.setCentralWidget(tabs)
 
@@ -49,24 +68,23 @@ class MainWindow(QtWidgets.QMainWindow):
         self.setStatusBar(self.status)
 
     def add_menu(self):
-        action_exit = QtWidgets.QAction(QtGui.QIcon(), '&Exit', self)
-        action_exit.setShortcut(QKeySequence('Ctrl+Q'))
-        action_exit.setStatusTip('Exit application')
+        action_exit = QtWidgets.QAction(QtGui.QIcon(), "&Exit", self)
+        action_exit.setShortcut(QKeySequence("Ctrl+Q"))
+        action_exit.setStatusTip("Exit application")
         action_exit.triggered.connect(self.close)
 
         menu = self.menuBar()
-        menu.setNativeMenuBar(QSysInfo.productType() != 'osx')
+        menu.setNativeMenuBar(QSysInfo.productType() != "osx")
         menu_file = menu.addMenu("&File")
         menu_file.addAction(action_exit)
 
         action_help = QtWidgets.QAction(QtGui.QIcon(), "&Documentation", self)
-        action_help.setStatusTip('Open online documentation')
+        action_help.setStatusTip("Open online documentation")
         action_help.setShortcut(QKeySequence(QKeySequence.HelpContents))
         action_help.triggered.connect(open_url(URL_READTHEDOCS))
 
-        action_bug_report = QtWidgets.QAction(QtGui.QIcon(),
-                                              "&Report an Issue", self)
-        action_bug_report.setStatusTip('Open online bug report form')
+        action_bug_report = QtWidgets.QAction(QtGui.QIcon(), "&Report an Issue", self)
+        action_bug_report.setStatusTip("Open online bug report form")
         action_bug_report.triggered.connect(open_url(URL_GITLAB_ISSUES))
 
         action_about = QtWidgets.QAction(QtGui.QIcon(), "&About", self)
@@ -79,11 +97,28 @@ class MainWindow(QtWidgets.QMainWindow):
         menu_help.addAction(action_about)
 
     def closeEvent(self, event):
+        if config_to_settings(self.app_data.config) != config_to_settings(
+            load_config()
+        ):
+            reply = QtWidgets.QMessageBox.question(
+                self,
+                "Persist changed settings?",
+                "You made changes to settings you did not persist yet, "
+                "do you want to permanently persist them to your sett configuration file?",
+                QtWidgets.QMessageBox.Yes | QtWidgets.QMessageBox.No,
+                QtWidgets.QMessageBox.No,
+            )
+            if reply == QtWidgets.QMessageBox.Yes:
+                save_config(config_to_dict(self.app_data.config))
+
         if self.app_data.config.gui_quit_confirmation:
             reply = QtWidgets.QMessageBox.question(
-                self, "Quit", "Do you really want to quit?",
+                self,
+                "Quit",
+                "Do you really want to quit?",
                 QtWidgets.QMessageBox.Yes | QtWidgets.QMessageBox.No,
-                QtWidgets.QMessageBox.No)
+                QtWidgets.QMessageBox.No,
+            )
             if reply == QtWidgets.QMessageBox.Yes:
                 event.accept()
             else:
@@ -95,18 +130,11 @@ class MainWindow(QtWidgets.QMainWindow):
 
         def get_warnings():
             with warnings.catch_warnings(record=True) as w:
-                check_version(self.app_data.config.repo_url)
+                check_version(self.app_data.config.repo_url, gui_formatting=True)
                 return "\n".join(format(warning.message) for warning in w)
 
-        def show_msg(text):
-            msg = QtWidgets.QMessageBox(parent=self)
-            msg.setIcon(QtWidgets.QMessageBox.Warning)
-            msg.setWindowTitle(f"{self.title}")
-            msg.setText(text)
-            msg.show()
-
         worker = Worker(get_warnings)
-        worker.signals.result.connect(lambda x: x and show_msg(x))
+        worker.signals.result.connect(lambda x: x and self.show_warning(self.title, x))
         QtCore.QThreadPool.globalInstance().start(worker)
 
     def show_about(self):
@@ -125,12 +153,20 @@ class MainWindow(QtWidgets.QMainWindow):
             f"<a href='{URL_GITLAB}'>{URL_GITLAB}</a><br><br>"
             f"{APP_NAME_SHORT} is developed as part of the "
             f"<a href='https://sphn.ch/network/projects/biomedit/'>BioMedIT "
-            f"project</a>")
+            f"project</a>"
+        )
+        msg.show()
+
+    def show_warning(self, title: str, text: str):
+        msg = QtWidgets.QMessageBox(parent=self)
+        msg.setWindowTitle(title)
+        msg.setIcon(QtWidgets.QMessageBox.Warning)
+        msg.setText(text)
         msg.show()
 
 
 def open_url(url: str):
-    """Retruns a function that will opens the specified URL in the user's
+    """Returns a function that will opens the specified URL in the user's
     default browser when called. The function that is returned has no
     arguments.
     :param url: URL to open.
