@@ -1,7 +1,18 @@
 from collections import defaultdict
 from dataclasses import dataclass, field
 from pathlib import Path
-from typing import Any, Dict, Hashable, Iterable, List, Optional, Tuple, Union, Sequence, Callable
+from typing import (
+    Any,
+    Dict,
+    Hashable,
+    Iterable,
+    List,
+    Optional,
+    Tuple,
+    Union,
+    Sequence,
+    Callable,
+)
 
 from PySide2 import QtCore
 
@@ -10,12 +21,14 @@ from ..utils.config import Config
 
 
 class TableModel(QtCore.QAbstractTableModel):
-    def __init__(self, data: Sequence[Sequence[Any]] = (),
-                 columns: Optional[Tuple[str, ...]] = None):
+    def __init__(
+        self,
+        data: Sequence[Sequence[Any]] = (),
+        columns: Optional[Tuple[str, ...]] = None,
+    ):
         super().__init__()
         self.set_data(data or tuple(tuple()))
-        self.columns = columns or tuple(
-            map(str, range(self.columnCount())))
+        self.columns = columns or tuple(map(str, range(self.columnCount())))
 
     @property
     def columns(self) -> Tuple[str, ...]:
@@ -33,7 +46,8 @@ class TableModel(QtCore.QAbstractTableModel):
         self.layoutChanged.emit()
         self.dataChanged.emit(
             self.createIndex(0, 0),
-            self.createIndex(self.rowCount(), self.columnCount()))
+            self.createIndex(self.rowCount(), self.columnCount()),
+        )
 
     def rowCount(self, _parent: QtCore.QModelIndex = QtCore.QModelIndex()) -> int:
         return len(self._data)
@@ -41,8 +55,9 @@ class TableModel(QtCore.QAbstractTableModel):
     def columnCount(self, _parent: QtCore.QModelIndex = QtCore.QModelIndex()) -> int:
         return len(self._data) and len(self._data[0])
 
-    def headerData(self, section: int, orientation=QtCore.Qt.Horizontal,
-                   role=QtCore.Qt.DisplayRole) -> Optional[str]:
+    def headerData(
+        self, section: int, orientation=QtCore.Qt.Horizontal, role=QtCore.Qt.DisplayRole
+    ) -> Optional[str]:
         if orientation == QtCore.Qt.Horizontal and role == QtCore.Qt.DisplayRole:
             return self._columns[section]
         if orientation == QtCore.Qt.Vertical and role == QtCore.Qt.DisplayRole:
@@ -50,8 +65,9 @@ class TableModel(QtCore.QAbstractTableModel):
         return None
 
     # Default value Qt.DisplayRole for index is not an int (upstream issue):
-    def data(self, index: QtCore.QModelIndex,  # type: ignore
-             role: int) -> Optional[Hashable]:
+    def data(  # type: ignore
+        self, index: QtCore.QModelIndex, role: int
+    ) -> Optional[Hashable]:
         if role == QtCore.Qt.DisplayRole:
             return self._data[index.row()][index.column()]
         return None
@@ -59,8 +75,7 @@ class TableModel(QtCore.QAbstractTableModel):
     def removeRows(self, row: int, count: int, _parent=QtCore.QModelIndex()) -> bool:
         if row > -1 and row + count <= self.rowCount():
             self.beginRemoveRows(QtCore.QModelIndex(), row, row + count - 1)
-            self.set_data(self.get_data()[:row] +
-                          self.get_data()[row + count:])
+            self.set_data(self.get_data()[:row] + self.get_data()[row + count :])
             self.endRemoveRows()
             return True
         return False
@@ -70,10 +85,8 @@ class KeyValueListModel(QtCore.QAbstractListModel):
     """List model extension for key-value objects."""
 
     def __init__(
-            self,
-            *args,
-            data: Optional[Iterable[Tuple[Hashable, Any]]] = None,
-            **kwargs):
+        self, *args, data: Optional[Iterable[Tuple[Hashable, Any]]] = None, **kwargs
+    ):
         super().__init__(*args, **kwargs)
         self.set_data(data or [])
 
@@ -83,7 +96,7 @@ class KeyValueListModel(QtCore.QAbstractListModel):
         self.layoutChanged.emit()
 
     # Default value Qt.DisplayRole for index is not an int (upstream issue):
-    def data(self, index, role) -> Optional[Hashable]:   # type: ignore
+    def data(self, index, role) -> Optional[Hashable]:  # type: ignore
         if role == QtCore.Qt.DisplayRole:
             return self._keys[index.row()]
         return None
@@ -122,15 +135,13 @@ class AppData:
     transfer_files: List[str] = field(default_factory=list)
     transfer_verify_dtr: bool = True
 
-    priv_keys_model: KeyValueListModel = field(
-        default_factory=KeyValueListModel)
-    pub_keys_model: KeyValueListModel = field(
-        default_factory=KeyValueListModel)
+    priv_keys_model: KeyValueListModel = field(default_factory=KeyValueListModel)
+    pub_keys_model: KeyValueListModel = field(default_factory=KeyValueListModel)
     default_key_index: Optional[int] = None
 
     def __setattr__(self, attr, value):
         super().__setattr__(attr, value)
-        if hasattr(self, '_listeners'):
+        if hasattr(self, "_listeners"):
             for callback in self._listeners[attr]:
                 callback()
 
@@ -138,7 +149,8 @@ class AppData:
         self._listeners[attr].append(listener)
 
     def __post_init__(self):
-        self._listeners = defaultdict(list) # pylint: disable=attribute-defined-outside-init
+        # pylint: disable=attribute-defined-outside-init
+        self._listeners = defaultdict(list)
         if self.config.offline:
             self.encrypt_verify_dtr = self.transfer_verify_dtr = False
         if self.config.output_dir:
