@@ -15,6 +15,7 @@ class LoggerHandler(logging.Handler):
         if self.callback:
             self.callback(self.format(record))
 
+
 class WorkerSignals(QObject):
     started = Signal()
     finished = Signal()
@@ -33,11 +34,8 @@ class Worker(QRunnable):
     :param logger: logs from those loggers are passed to the logging
                    signal
     """
-    def __init__(self,
-                 fn,
-                 *args,
-                 logger: Collection[logging.Logger] = (),
-                 **kwargs):
+
+    def __init__(self, fn, *args, logger: Collection[logging.Logger] = (), **kwargs):
         super().__init__()
         self.fn = fn
         self.args = args
@@ -49,7 +47,8 @@ class Worker(QRunnable):
         try:
             logger_handler = LoggerHandler(callback=self.signals.logging.emit)
             logger_handler.setFormatter(
-                logging.Formatter("[%(levelname)s] %(message)s"))
+                logging.Formatter("[%(levelname)s] %(message)s")
+            )
             logger_handler.setLevel(logging.INFO)
             for x in self.logger:
                 x.addHandler(logger_handler)
