@@ -23,10 +23,12 @@ class ProgressInterface:
         """
 
 
-def progress_iter(iterable: Iterable,
-                  progress: ProgressInterface = None,
-                  weights: List[float] = None,
-                  iterable_length: int = None) -> Iterable:
+def progress_iter(
+    iterable: Iterable,
+    progress: ProgressInterface = None,
+    weights: List[float] = None,
+    iterable_length: int = None,
+) -> Iterable:
     """Add progress tracking through a ProgressInterface to an iterable object.
     :param iterable: iterable object to which progress tracking is added.
     :param progress: progress interface objects that will take care of
@@ -49,16 +51,18 @@ def progress_iter(iterable: Iterable,
     # At the end, send signal that completion reached 100% to the progress
     # interface.
     else:
-        yield from _progress_iter_common(_progress_wrapper, iterable,
-                                         progress, weights, iterable_length)
+        yield from _progress_iter_common(
+            _progress_wrapper, iterable, progress, weights, iterable_length
+        )
         progress.update(1.0)
 
 
 def progress_iter_with_sub_progress(
-        iterable: Iterable,
-        progress: Optional[ProgressInterface] = None,
-        weights: List[float] = None,
-        iterable_length: int = None) -> Iterable:
+    iterable: Iterable,
+    progress: Optional[ProgressInterface] = None,
+    weights: List[float] = None,
+    iterable_length: int = None,
+) -> Iterable:
     """Add progress tracking through a ProgressInterface to an iterable object.
     The difference with 'progress_iter' is that items of the returned iterable
     will now contain tuples consisting of the original item and a
@@ -74,15 +78,22 @@ def progress_iter_with_sub_progress(
 
     # Return tuples of the original iterable values and an associated
     # ProgressInterface.
-    return _progress_iter_common(_progress_wrapper_with_sub_progress, iterable,
-                                 progress, weights, iterable_length)
+    return _progress_iter_common(
+        _progress_wrapper_with_sub_progress,
+        iterable,
+        progress,
+        weights,
+        iterable_length,
+    )
 
 
-def _progress_iter_common(wrapper: Callable,
-                          iterable: Iterable,
-                          progress: ProgressInterface = None,
-                          weights: Optional[Sequence[float]] = None,
-                          iterable_length: int = None) -> Iterable:
+def _progress_iter_common(
+    wrapper: Callable,
+    iterable: Iterable,
+    progress: ProgressInterface = None,
+    weights: Optional[Sequence[float]] = None,
+    iterable_length: int = None,
+) -> Iterable:
     """Iterate over all values in the input iterable and apply the specified
     wrapper function to them. The wrapper function must accept arguments that
     have the form (item, (start_position, stop)).
@@ -91,8 +102,10 @@ def _progress_iter_common(wrapper: Callable,
     if isinstance(iterable, Collection):
         iterable_length = iterable.__len__()
     elif iterable_length is None:
-        raise ValueError('iterable has no length attribute and no value was'
-                         'passed for parameter [iterable_length] either.')
+        raise ValueError(
+            "iterable has no length attribute and no value was"
+            "passed for parameter [iterable_length] either."
+        )
 
     # If no weight were provided, assume equal weights for all iterations.
     if weights is None:
@@ -108,8 +121,9 @@ def _progress_iter_common(wrapper: Callable,
     return map(update_progress, zip(iterable, ranges))
 
 
-def weights_to_ranges(weights: Sequence[float],
-                      start: float = 0.) -> Iterable[Tuple[float, float]]:
+def weights_to_ranges(
+    weights: Sequence[float], start: float = 0.0
+) -> Iterable[Tuple[float, float]]:
     """Splits the range (0.0, 1.0) into a number of sub-ranges equal to the
     number of weights, with the size of each sub-range proportional to the
     value of its weights.
@@ -136,8 +150,10 @@ def _progress_wrapper(progress: ProgressInterface) -> Callable:
     iterable is the iterable for which we track progress and range is a tuple
     (start, stop) giving the range of completion fractions for the iterable.
     """
-    def progress_wrapper(item_with_range: Tuple[Iterable, Tuple[float, float]]
-                         ) -> Iterable:
+
+    def progress_wrapper(
+        item_with_range: Tuple[Iterable, Tuple[float, float]]
+    ) -> Iterable:
         """item_with_range: iterable and its completion range
         :return: The bare item
         """
@@ -148,14 +164,15 @@ def _progress_wrapper(progress: ProgressInterface) -> Callable:
     return progress_wrapper
 
 
-def _progress_wrapper_with_sub_progress(progress: ProgressInterface) \
-        -> Callable:
+def _progress_wrapper_with_sub_progress(progress: ProgressInterface) -> Callable:
     """Return a function that takes an 'item_with_range' and return the
     iterable item with an associated ProgressInterface that does automatic
     rescaling of its .update() method in the range of 'item_with_range'.
     """
-    def progress_wrapper(item_with_range: Tuple[Iterable, Tuple[float, float]]
-                         ) -> Tuple[Iterable, Optional[ProgressInterface]]:
+
+    def progress_wrapper(
+        item_with_range: Tuple[Iterable, Tuple[float, float]]
+    ) -> Tuple[Iterable, Optional[ProgressInterface]]:
         """item_with_range: iterable and its completion range
         :return: A tuple consisting of the bare item and a ProgressInterface instance
         """
@@ -166,9 +183,9 @@ def _progress_wrapper_with_sub_progress(progress: ProgressInterface) \
     return progress_wrapper
 
 
-def scale_progress(progress: ProgressInterface,
-                   start: float,
-                   stop: float) -> Optional[ProgressInterface]:
+def scale_progress(
+    progress: ProgressInterface, start: float, stop: float
+) -> Optional[ProgressInterface]:
     """Create an instance of a ProgressInterface with a modified .update
     method that rescales the value of the 'completed_fraction' to be in the
     range (start, stop).
@@ -187,7 +204,6 @@ def scale_progress(progress: ProgressInterface,
     # method is modified so it automatically rescales its inputs to the
     # desired range of values.
     class SubProgress(ProgressInterface):
-
         def update(self, completed_fraction: float) -> None:
             """Rescale the completed_fraction value so that its value is
             in the range [start-stop].
@@ -207,8 +223,7 @@ def scale_progress(progress: ProgressInterface,
 
 
 @contextmanager
-def subprogress(progress: Optional[ProgressInterface],
-                step_completion_increase: float):
+def subprogress(progress: Optional[ProgressInterface], step_completion_increase: float):
     """Context manager for running a progress bar or a subset of a progress
     bar (i.e. a "scaled progress".
     Usage example:
@@ -233,9 +248,11 @@ def subprogress(progress: Optional[ProgressInterface],
     start = progress.get_completed_fraction()
     stop = start + step_completion_increase
     if stop > 1.0:
-        raise ValueError(f'progress interface completion value cannot be > 1. '
-                         f'Value passed for \'completed_fraction_increase\' '
-                         f'[{step_completion_increase}] is too large.')
+        raise ValueError(
+            f"progress interface completion value cannot be > 1. "
+            f"Value passed for 'completed_fraction_increase' "
+            f"[{step_completion_increase}] is too large."
+        )
     yield scale_progress(progress, start, stop)
 
 
@@ -254,16 +271,20 @@ class FileObjectProgress:
         f_obj.seek(original_pos)
 
         if total_size == 0:
+
             def wrap_update(f):
                 progress.update(1)
                 return f
+
         else:
+
             def wrap_update(f):
                 @wraps(f)
                 def wrapped_f(*args, **kwargs):
                     data = f(*args, **kwargs)
                     progress.update((f_obj.tell() - original_pos) / total_size)
                     return data
+
                 return wrapped_f
 
         for f_name in ("__next__", "read", "readline", "readlines"):
@@ -291,7 +312,7 @@ class FileObjectProgress:
 
     @property
     def name(self):
-        return self.__getattr__('name')
+        return self.__getattr__("name")
 
 
 def with_progress(f: IO[bytes], progress: Optional[ProgressInterface]) -> IO[bytes]:
@@ -328,10 +349,9 @@ class Opener:
         return self._f.__exit__(*args)
 
 
-def progress_file_iter(files: List[str],
-                       mode: str,
-                       progress: Optional[ProgressInterface]) \
-        -> Iterable[IO[bytes]]:
+def progress_file_iter(
+    files: List[str], mode: str, progress: Optional[ProgressInterface]
+) -> Iterable[IO[bytes]]:
     """Associate, to each input file, a sub-progress object whose contribution
     to the increase in completion of the input progress object is proportional
     to the file's size. The output is an iterator of file objects with their
@@ -347,15 +367,13 @@ def progress_file_iter(files: List[str],
     """
     file_size = [float(os.path.getsize(f)) for f in files]
     files_with_progress = progress_iter_with_sub_progress(
-        iterable=files,
-        progress=progress,
-        weights=file_size,
-        iterable_length=len(files))
+        iterable=files, progress=progress, weights=file_size, iterable_length=len(files)
+    )
     for file, sub_progress in files_with_progress:
-        yield cast(IO[bytes], Opener(
-            file,
-            mode=mode,
-            wrapper=with_progress_decorator(sub_progress)))
+        yield cast(
+            IO[bytes],
+            Opener(file, mode=mode, wrapper=with_progress_decorator(sub_progress)),
+        )
 
 
 def with_progress_decorator(progress):
